@@ -25,8 +25,7 @@
 #include <stdlib.h>
 #include <errno.h>
 
-/* FIXME */
-#define _(x) x
+#include "glibintl.h"
 
 GQuark
 g_markup_error_quark ()
@@ -778,7 +777,7 @@ find_current_text_end (GMarkupParseContext *context)
   const gchar *p;
   const gchar *next;
 
-  g_assert (p != end);
+  g_assert (context->current_text_len > 0);
 
   p = context->current_text;
   next = g_utf8_find_next_char (p, end);
@@ -1263,8 +1262,8 @@ g_markup_parse_context_parse (GMarkupParseContext *context,
                   if (context->parser->start_element)
                     (* context->parser->start_element) (context,
                                                         start_name,
-                                                        attr_names,
-                                                        attr_values,
+                                                        (const gchar **)attr_names,
+                                                        (const gchar **)attr_values,
                                                         context->user_data,
                                                         &tmp_error);
 
